@@ -24,7 +24,10 @@ namespace qrk
     Audio(void);
     ~Audio(void);
 
+    const char* what(void) const;
+
     bool initialize(void);
+    bool isInitialized(void);
   };
 }
 
