@@ -4,7 +4,7 @@
 
   \author Satofumi KAMIMURA
 
-  $Id: FlyFlapp.cpp 700 2009-03-30 22:31:13Z satofumi $
+  $Id: FlyFlapp.cpp 712 2009-04-05 12:25:30Z satofumi $
 
   \todo ウィンドウのキャプションを設定する
 */
@@ -43,7 +43,7 @@ namespace
     luabindSystem();
     luabindGeometry();
     luabindGui();
-    // luabindAudio();
+    luabindAudio();
     luabindFlyFlapp();
   }
 }
@@ -61,8 +61,8 @@ int main(int argc, char *argv[])
   // 音源の初期化
   bool is_mute = parseArgs(argc, argv);
   if (! is_mute) {
-    // Audio audio;
-    // audio.initialize();
+    Audio audio;
+    audio.initialize();
   }
 
   // Lua の初期化と実行
